import { BaseApi } from '../base';
import { SummonerLeagueDto } from '../../dto/League/SummonerLeague/SummonerLeague.dto';
import { LeagueEntryDTO } from '../../dto/League/LeagueExp/LeagueEntry.dto';
import { Queues, Tiers, Divisions, Regions } from '../../constants';
import { LeagueListDTO } from '../../dto/League/LeagueItem/LeagueList.dto';
/**
 * League methods
 */
export declare class LeagueApi extends BaseApi {
    /**
     * Get summoner leagues
     * @param encryptedSummonerId Encrypted summoner ID. Max length 63 characters.
     * @param region
     */
    bySummoner(encryptedSummonerId: string, region: Regions): Promise<import("../../dto").ApiResponseDTO<SummonerLeagueDto[]>>;
    /**
     * Top league exp
     * @param queue Note that the queue value must be a valid ranked queue.
     * @param tier
     * @param division
     * @param region
     */
    exp(queue: Queues, tier: Tiers, division: Divisions, region: Regions): Promise<import("../../dto").ApiResponseDTO<LeagueEntryDTO>>;
    /**
     * League entries
     * @param queue Note that the queue value must be a valid ranked queue.
     * @param tier
     * @param division
     * @param region
     */
    entries(queue: Queues, tier: Tiers, division: Divisions, region: Regions): Promise<import("../../dto").ApiResponseDTO<LeagueEntryDTO>>;
    /**
     * Get league by id
     * @param leagueId
     * @param region
     */
    get(leagueId: string, region: Regions): Promise<import("../../dto").ApiResponseDTO<LeagueListDTO>>;
    /**
     * Get challenger league by queue
     * @param queue Note that the queue value must be a valid ranked queue.
     * @param region
     */
    getChallengerLeaguesByQueue(queue: Queues, region: Regions): Promise<import("../../dto").ApiResponseDTO<LeagueListDTO>>;
    /**
     * Get grandmaster league by queue
     * @param queue Note that the queue value must be a valid ranked queue.
     * @param region
     */
    getGrandMasterLeagueByQueue(queue: Queues, region: Regions): Promise<import("../../dto").ApiResponseDTO<LeagueListDTO>>;
    /**
     * Get master league by queue
     * @param queue Note that the queue value must be a valid ranked queue.
     * @param region
     */
    getMasterLeagueByQueue(queue: Queues, region: Regions): Promise<import("../../dto").ApiResponseDTO<LeagueListDTO>>;
}
